@@ -1,8 +1,10 @@
 # Copyright 2017 Palantir Technologies, Inc.
+import sys
+from pyls import uris
 from pyls.plugins.completion import pyls_completions
 from pyls.workspace import Document
 
-DOC_URI = __file__
+DOC_URI = uris.from_fs_path(__file__)
 DOC = """import sys
 print sys.stdin.read()
 
@@ -22,7 +24,10 @@ def test_completion():
     items = pyls_completions(doc, com_position)
 
     assert len(items) > 0
-    assert items[0]['label'] == 'read'
+    if (sys.version_info > (3, 0)):
+        assert items[0]['label'] == 'read(args)'
+    else:
+        assert items[0]['label'] == 'read()'
 
 
 def test_completion_ordering():
@@ -34,6 +39,6 @@ def test_completion_ordering():
     items = {c['label']: c['sortText'] for c in completions}
 
     # Assert that builtins come after our own functions even if alphabetically they're before
-    assert items['hello'] < items['dict']
+    assert items['hello()'] < items['dict']
     # And that 'hidden' functions come after unhidden ones
-    assert items['hello'] < items['_a_hello']
+    assert items['hello()'] < items['_a_hello()']
